"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const result_reporter_old_1 = require("./openapi-diff/result-reporter-old");
const spec_differ_1 = require("./openapi-diff/spec-differ");
const spec_parser_1 = require("./openapi-diff/spec-parser");
exports.validateSourceAndDestinationSpecContent = ({ sourceSpec, destinationSpec }) => __awaiter(this, void 0, void 0, function* () {
    const parsedSourceSpec = spec_parser_1.specParser.parse(sourceSpec.content);
    const parsedDestinationSpec = spec_parser_1.specParser.parse(destinationSpec.content);
    const resultsByType = yield validateSourceAndDestinationParsedSpecs(parsedSourceSpec, parsedDestinationSpec);
    const sourceSpecDetails = {
        format: parsedSourceSpec.format,
        location: sourceSpec.location
    };
    const destinationSpecDetails = {
        format: parsedDestinationSpec.format,
        location: destinationSpec.location
    };
    return generateValidationOutcome(resultsByType, sourceSpecDetails, destinationSpecDetails);
});
const generateValidationOutcome = (resultsByType, sourceSpecDetails, destinationSpecDetails) => {
    const success = resultsByType.breakingDifferences.length === 0;
    const failureReason = success
        ? undefined
        : createFailureReason(sourceSpecDetails.location, destinationSpecDetails.location);
    return {
        breakingDifferences: resultsByType.breakingDifferences,
        destinationSpecDetails,
        failureReason,
        nonBreakingDifferences: resultsByType.nonBreakingDifferences,
        sourceSpecDetails,
        success,
        unclassifiedDifferences: resultsByType.unclassifiedDifferences
    };
};
const createFailureReason = (sourceLocation, destinationLocation) => `destination spec "${destinationLocation}" introduced breaking changes ` +
    `with respect to source spec "${sourceLocation}"`;
const validateSourceAndDestinationParsedSpecs = (source, destination) => __awaiter(this, void 0, void 0, function* () {
    const allResults = yield spec_differ_1.specDiffer.diff(source, destination);
    return {
        breakingDifferences: allResults.filter((result) => result.type === 'breaking'),
        nonBreakingDifferences: allResults.filter((result) => result.type === 'non-breaking'),
        unclassifiedDifferences: allResults.filter((result) => result.type === 'unclassified')
    };
});
class OpenApiDiff {
    constructor(specLoader) {
        this.specLoader = specLoader;
    }
    validate(sourceSpecPath, destinationSpecPath) {
        return __awaiter(this, void 0, void 0, function* () {
            const { sourceSpec, destinationSpec } = yield this.loadSpecs(sourceSpecPath, destinationSpecPath);
            const validationOutcome = yield exports.validateSourceAndDestinationSpecContent({
                destinationSpec: {
                    content: destinationSpec,
                    location: destinationSpecPath
                },
                sourceSpec: {
                    content: sourceSpec,
                    location: sourceSpecPath
                }
            });
            return result_reporter_old_1.resultReporterOld.build(validationOutcome);
        });
    }
    loadSpecs(sourceSpecPath, destinationSpecPath) {
        return __awaiter(this, void 0, void 0, function* () {
            const whenSourceSpec = this.specLoader.load(sourceSpecPath);
            const whenDestinationSpec = this.specLoader.load(destinationSpecPath);
            const [sourceSpec, destinationSpec] = yield Promise.all([whenSourceSpec, whenDestinationSpec]);
            return { sourceSpec, destinationSpec };
        });
    }
}
exports.OpenApiDiff = OpenApiDiff;
