"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const validation_result_to_diff_entry_1 = require("./common/validation-result-to-diff-entry");
const buildChangeSentence = (targetChange) => {
    const changeDescription = {
        'add': ((change) => {
            return `${_.capitalize(change.severity)}: the path [${change.printablePath.join('/')}] `
                + `was added with value \'${change.destinationValue}\'`;
        }),
        'arrayContent.add': ((change) => {
            return `${_.capitalize(change.severity)}: the value \'${change.destinationValue}\' was added to the`
                + ` array in the path [${change.printablePath.join('/')}]`;
        }),
        'arrayContent.delete': ((change) => {
            return `${_.capitalize(change.severity)}: the value \'${change.sourceValue}\' was removed from the`
                + ` array in the path [${change.printablePath.join('/')}]`;
        }),
        'delete': ((change) => {
            return `${_.capitalize(change.severity)}: the path [${change.printablePath.join('/')}] `
                + `with value \'${change.sourceValue}\' was removed`;
        }),
        'edit': ((change) => {
            return `${_.capitalize(change.severity)}: the path [${change.printablePath.join('/')}] `
                + `was modified from \'${change.sourceValue}\' to \'${change.destinationValue}\'`;
        })
    };
    return changeDescription[targetChange.type](targetChange);
};
exports.resultReporterOld = {
    build: (validationOutcome) => {
        const changeList = [];
        const summary = [];
        summary.push(`${validationOutcome.breakingDifferences.length} breaking changes found.`);
        summary.push(`${validationOutcome.nonBreakingDifferences.length} non-breaking changes found.`);
        summary.push(`${validationOutcome.unclassifiedDifferences.length} unclassified changes found.`);
        const allOutcomes = validationOutcome.breakingDifferences
            .concat(validationOutcome.unclassifiedDifferences)
            .concat(validationOutcome.nonBreakingDifferences);
        for (const outcome of allOutcomes) {
            changeList.push(buildChangeSentence(validation_result_to_diff_entry_1.toDiffEntry(outcome)));
        }
        return {
            changeList: _.sortBy(changeList),
            hasBreakingChanges: validationOutcome.breakingDifferences.length > 0,
            summary
        };
    }
};
