"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const yaml = require("js-yaml");
const url = require("url");
const VError = require("verror");
class SpecLoader {
    constructor(httpClient, fileSystem) {
        this.httpClient = httpClient;
        this.fileSystem = fileSystem;
    }
    static parseSpec(location, content) {
        try {
            return Promise.resolve(SpecLoader.parseJson(location, content));
        }
        catch (parseJsonError) {
            try {
                return Promise.resolve(SpecLoader.parseYaml(location, content));
            }
            catch (parseYamlError) {
                return Promise.reject(parseYamlError);
            }
        }
    }
    static parseJson(location, content) {
        try {
            return JSON.parse(content);
        }
        catch (error) {
            throw new VError(`ERROR: unable to parse ${location} as a JSON or YAML file`);
        }
    }
    static parseYaml(location, content) {
        let parsedYaml = null;
        try {
            parsedYaml = yaml.safeLoad(content);
        }
        catch (error) {
            throw new VError(`ERROR: unable to parse ${location} as a JSON or YAML file`);
        }
        if (!parsedYaml) {
            throw new VError(`ERROR: unable to parse ${location} as a JSON or YAML file`);
        }
        return parsedYaml;
    }
    static isUrl(location) {
        const urlObject = url.parse(location);
        return urlObject.protocol !== null;
    }
    load(location) {
        return __awaiter(this, void 0, void 0, function* () {
            const fileContents = SpecLoader.isUrl(location)
                ? yield this.httpClient.get(location)
                : yield this.fileSystem.readFile(location);
            return SpecLoader.parseSpec(location, fileContents);
        });
    }
}
exports.SpecLoader = SpecLoader;
